@@ -9,9 +9,9 @@ function (loop.data, bn.data) {
     y1 <- head(peers, n=1)[2]
     y2 <- tail(peers, n=1)[2]
 
-    line      <- list(c(x1, x2), c(y1, y2))
     slope     <- (y2 - y1) / (x2 - x1)
     intercept <- y2 - (slope * x2)
+    line      <- c(intercept, slope)
     ceiling   <- p_ceiling(loop.data, slope, intercept)
     effect    <- ceiling / loop.data$scope.area
     ineffs    <- p_ineffs(loop.data, slope, intercept)
@@ -25,12 +25,14 @@ function (loop.data, bn.data) {
     ineffs    <- list(x=NA, y=NA, abs=NA, rel=NA)
     above     <- NA    
   }
-  
+
+  accuracy    <- p_accuracy(loop.data, above)
+  fit         <- get_fit(ceiling, loop.data$ce_fdh_ceiling)
   bottleneck  <- p_bottleneck(loop.data, bn.data, slope, intercept)
 
   return(list(line=line,
               slope=slope, intercept=intercept,
               ceiling=ceiling, effect=effect,
-              ineffs=ineffs, above=above,
-              bottleneck=bottleneck))
+              above=above, accuracy=accuracy, fit=fit,
+              ineffs=ineffs, bottleneck=bottleneck))
 }
\ No newline at end of file
